﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace PersistTreeView
{
    public partial class Site1 : System.Web.UI.MasterPage
    {
        private string strState = null;
        private int intStatePosition = -1;

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                //Estado del árbol almacenado en cookies
                if (Request.Cookies.Get("TreeViewState") != null)
                    strState = Request.Cookies.Get("TreeViewState").Value;

                //Nodo raiz del árbol
                TreeNode objRootNode = new TreeNode("Nodo raíz");
                trvChannels.Nodes.Add(objRootNode);
                LoadNodeState(objRootNode);
                SubNodes(objRootNode);
            }

            //Guardo en una variable de JavaScript el ID de cliente del campo oculto
            //donde .NET guarda el estado del mismo
            Page.ClientScript.RegisterClientScriptBlock(
                typeof(Site1),
                "TreeViewState",
                "var idTreeViewState='" + trvChannels.ClientID + "_ExpandState';",
                true);
        }

        /// <summary>
        /// Crea los subnodos de un nodo dado
        /// </summary>
        /// <param name="ParentNode">Nodo padre</param>
        private void SubNodes(TreeNode ParentNode)
        {
            for (int intPos = 1; intPos < 6; intPos++)
            {
                TreeNode objNewNode = new TreeNode();
                ParentNode.ChildNodes.Add(objNewNode);
                objNewNode.Text = "Nodo " + intPos.ToString();
                LoadNodeState(objNewNode);
                if (objNewNode.Depth < 4)
                    SubNodes(objNewNode);
            }

        }

        /// <summary>
        /// Establece el estado de "expandido" o no al nodo
        /// dependiendo del valor de la cookie
        /// </summary>
        /// <param name="Node">Nodo</param>
        private void LoadNodeState(TreeNode Node)
        {
            if (strState != null && strState.Length > ++intStatePosition)
                Node.Expanded = strState[intStatePosition] == 'e';
        }

        protected void trvChannels_SelectedNodeChanged(object sender, EventArgs e)
        {
            lblSelectedNode.Text = "Nodo seleccionado: " + trvChannels.SelectedNode.ValuePath;
        }
    }
}